# btn.py

import machine
from sys import platform
ESP32 = platform == 'esp32'
RP2 = platform == 'rp2'
PYBOARD = platform == 'pyboard'
if ESP32 or RP2:
    from machine import Pin
else:
    from pyb import Pin, LED
import uasyncio as asyncio
#from primitives.switch import Switch
from primitives.delay_ms import Delay_ms
import primitives.queue as queue
from primitives import Switch, Pushbutton
from rgb import RGB


# Settings
#led = machine.Pin(25, machine.Pin.OUT)
led = machine.Pin("LED", machine.Pin.OUT) # Pi Pico onboard LED
btn = machine.Pin(18, machine.Pin.IN, machine.Pin.PULL_UP)


# Pulse an LED (coroutine)
async def pulse(led, ms):
    led.on()
    
    await asyncio.sleep_ms(ms)
    led.off()
    

# Pulse an LED when an event triggered
async def evt_pulse(event, rgb, set):
    while True:
        event.clear()
        await event.wait()
     #  led.on()
        await set()
        await asyncio.sleep_ms(300)
     #  led.off()
        await rgb.off()


# Toggle an LED (callback)
def toggle(led):
    led.toggle()


# Quit test by connecting X2 to ground
async def killer(obj):
    pin = btn
    while pin.value():
        await asyncio.sleep_ms(50)
    obj.deinit()
    await asyncio.sleep_ms(0)



# Test for the Pushbutton class (events)
async def do_btn_event():
    #led.off()
    rgb = RGB()
    pb = Pushbutton(btn)
    pb.press_func(None)
    pb.release_func(None)
    pb.double_func(None)
    pb.long_func(None)
    tasks = []
    for event, rgb, set in ((pb.press, rgb, rgb.set_blue), 
                            (pb.release, rgb, rgb.set_green), 
                            (pb.double, rgb, rgb.set_yellow), 
                            (pb.long, rgb, rgb.set_red)):
        asyncio.create_task(evt_pulse(event, rgb, set))
    
    #tasks.append(asyncio.create_task(evt_pulse(pb.double, led)))

    #asyncio.create_task(evt_pulse(pb.double, rgb))

    #await killer(pb)
    #for task in tasks:
    #    task.cancel()

    while True:
        await asyncio.sleep_ms(100)


 
    
print("Test of pushbutton triggering events.")
print("""
press pulse red
release pulses green
double click pulses yellow
long press pulses blue
""")
try:
        asyncio.run(do_btn_event())
except KeyboardInterrupt:
        print("Interrupted")
finally:
        asyncio.new_event_loop()
        print('tests complete')

